@@ -36,14 +36,17 @@ from pcluster.api.models import (
     CloudFormationStackStatus,
     ClusterConfigurationStructure,
     ClusterInfoSummary,
+    ClusterStatus,
     CreateClusterBadRequestExceptionResponseContent,
     CreateClusterRequestContent,
     CreateClusterResponseContent,
     DeleteClusterResponseContent,
     DescribeClusterResponseContent,
     EC2Instance,
+    Failure,
     InstanceState,
     ListClustersResponseContent,
+    Scheduler,
     Tag,
     UpdateClusterBadRequestExceptionResponseContent,
     UpdateClusterRequestContent,
@@ -54,6 +57,7 @@ from pcluster.api.models import (
 from pcluster.api.util import assert_valid_node_js
 from pcluster.aws.aws_api import AWSApi
 from pcluster.aws.common import StackNotFoundError
+from pcluster.config.config_patch import ConfigPatch
 from pcluster.config.update_policy import UpdatePolicy
 from pcluster.models.cluster import (
     Cluster,
@@ -135,6 +139,7 @@ def create_cluster(
                 region=os.environ.get("AWS_DEFAULT_REGION"),
                 version=get_installed_version(),
                 cluster_status=cloud_formation_status_to_cluster_status(CloudFormationStackStatus.CREATE_IN_PROGRESS),
+                scheduler=Scheduler(type=cluster.config.scheduling.scheduler),
             ),
             validation_messages=validation_results_to_config_validation_errors(ignored_validation_failures) or None,
         )
@@ -180,6 +185,7 @@ def delete_cluster(cluster_name, region=None):
                 region=os.environ.get("AWS_DEFAULT_REGION"),
                 version=cluster.stack.version,
                 cluster_status=cloud_formation_status_to_cluster_status(CloudFormationStackStatus.DELETE_IN_PROGRESS),
+                scheduler=Scheduler(type=cluster.stack.scheduler),
             )
         )
     except StackNotFoundError:
@@ -216,6 +222,7 @@ def describe_cluster(cluster_name, region=None):
         # Do not fail request when S3 bucket is not available
         LOGGER.error(e)
 
+    cluster_status = cloud_formation_status_to_cluster_status(cfn_stack.status)
     response = DescribeClusterResponseContent(
         creation_time=to_utc_datetime(cfn_stack.creation_time),
         version=cfn_stack.version,
@@ -227,7 +234,9 @@ def describe_cluster(cluster_name, region=None):
         cloudformation_stack_arn=cfn_stack.id,
         last_updated_time=to_utc_datetime(cfn_stack.last_updated_time),
         region=os.environ.get("AWS_DEFAULT_REGION"),
-        cluster_status=cloud_formation_status_to_cluster_status(cfn_stack.status),
+        cluster_status=cluster_status,
+        scheduler=Scheduler(type=cluster.stack.scheduler, metadata=cluster.get_plugin_metadata()),
+        failures=_get_creation_failures(cluster_status, cfn_stack),
     )
 
     try:
@@ -276,6 +285,7 @@ def list_clusters(region=None, next_token=None, cluster_status=None):
                 region=os.environ.get("AWS_DEFAULT_REGION"),
                 version=stack.version,
                 cluster_status=current_cluster_status,
+                scheduler=Scheduler(type=stack.scheduler),
             )
             clusters.append(cluster_info)
 
@@ -365,6 +375,7 @@ def update_cluster(
                 region=os.environ.get("AWS_DEFAULT_REGION"),
                 version=cluster.stack.version,
                 cluster_status=cloud_formation_status_to_cluster_status(CloudFormationStackStatus.UPDATE_IN_PROGRESS),
+                scheduler=Scheduler(type=cluster.stack.scheduler),
             ),
             validation_messages=validation_results_to_config_validation_errors(ignored_validation_failures) or None,
             change_set=change_set,
@@ -414,9 +425,9 @@ def _analyze_changes(changes):
     key_indexes = {key: index for index, key in enumerate(changes[0])}
 
     for row in changes[1:]:
-        parameter = _get_yaml_path(row[key_indexes["param_path"]], row[key_indexes["parameter"]])
-        new_value = row[key_indexes["new value"]]
-        old_value = row[key_indexes["old value"]]
+        parameter = ConfigPatch.build_config_param_path(row[key_indexes["param_path"]], row[key_indexes["parameter"]])
+        new_value = row[key_indexes["new value"]] if not row[key_indexes["new value"]] is None else "-"
+        old_value = row[key_indexes["old value"]] if not row[key_indexes["old value"]] is None else "-"
         check_result = row[key_indexes["check"]]
         message = _create_message(row[key_indexes["reason"]], row[key_indexes["action_needed"]])
         if not _cluster_update_change_succeded(check_result):
@@ -436,14 +447,9 @@ def _create_message(failure_reason, action_needed):
     return message or "Error during update"
 
 
-def _get_yaml_path(path, parameter):
-    """Compose the parameter path following the YAML Path standard.
-
-    Standard: https://github.com/wwkimball/yamlpath/wiki/Segments-of-a-YAML-Path#yaml-path-standard
-    """
-    yaml_path = []
-    if path:
-        yaml_path.extend(path)
-    if parameter:
-        yaml_path.append(parameter)
-    return ".".join(yaml_path)
+def _get_creation_failures(cluster_status, cfn_stack):
+    """Get a list of Failure objects containing failure code and reason when cluster creation failed."""
+    if cluster_status != ClusterStatus.CREATE_FAILED:
+        return None
+    failure_code, failure_reason = cfn_stack.get_cluster_creation_failure()
+    return [Failure(failure_code=failure_code, failure_reason=failure_reason)]
