@@ -58,6 +58,9 @@ def create_hash_suffix(string_to_hash: str):
     return (
         string_to_hash
         if string_to_hash == "HeadNode"
+        # A nosec comment is appended to the following line in order to disable the B324 check.
+        # The sha1 is used just as a hashing function.
+        # [B324:hashlib] Use of weak MD4, MD5, or SHA1 hash for security. Consider usedforsecurity=False
         else sha1(string_to_hash.encode("utf-8")).hexdigest()[:16].capitalize()  # nosec nosemgrep
     )
 
@@ -273,13 +276,13 @@ def add_cluster_iam_resource_prefix(stack_name, config, name: str, iam_type: str
     return full_resource_path, full_resource_name
 
 
-def add_lambda_cfn_role(scope, function_id: str, statements: List[iam.PolicyStatement], has_vpc_config: bool):
+def add_lambda_cfn_role(scope, config, function_id: str, statements: List[iam.PolicyStatement], has_vpc_config: bool):
     """Return a CfnRole to be used for a Lambda function."""
     role_path, role_name = add_cluster_iam_resource_prefix(
-        scope.config.cluster_name, scope.config, name=f"{function_id}Role", iam_type="AWS::IAM::Role"
+        config.cluster_name, config, name=f"{function_id}Role", iam_type="AWS::IAM::Role"
     )
     _, policy_name = add_cluster_iam_resource_prefix(
-        scope.config.cluster_name, scope.config, "LambdaPolicy", iam_type="AWS::IAM::Policy"
+        config.cluster_name, config, "LambdaPolicy", iam_type="AWS::IAM::Policy"
     )
 
     role_id = f"{function_id}Role" if role_name else f"{function_id}FunctionExecutionRole"
@@ -315,6 +318,9 @@ def generate_launch_template_version_cfn_parameter_hash(queue, compute_resource)
     :param compute_resource
     :return: 16 chars string e.g. 2238a84ac8a74529
     """
+    # A nosec comment is appended to the following line in order to disable the B324 check.
+    # The sha1 is used just as a hashing function.
+    # [B324:hashlib] Use of weak MD4, MD5, or SHA1 hash for security. Consider usedforsecurity=False
     return hashlib.sha1((queue + compute_resource).encode()).hexdigest()[0:16].capitalize()  # nosec nosemgrep
 
 
@@ -690,20 +696,18 @@ class HeadNodeIamResources(NodeIamResourcesBase):
                     ),
                 ]
             )
+
+            self._add_compute_console_output_policy_statement(policy)
+
             capacity_reservation_ids = self._config.capacity_reservation_ids
 
             if capacity_reservation_ids:
                 policy.append(
                     iam.PolicyStatement(
+                        sid="AllowRunningReservedCapacity",
                         actions=["ec2:RunInstances"],
                         effect=iam.Effect.ALLOW,
-                        resources=[
-                            self._format_arn(
-                                service="ec2",
-                                resource=f"capacity-reservation/{capacity_reservation_id}",
-                            )
-                            for capacity_reservation_id in capacity_reservation_ids
-                        ],
+                        resources=self._config.capacity_reservation_arns,
                     )
                 )
             capacity_reservation_resource_group_arns = self._config.capacity_reservation_resource_group_arns
@@ -711,6 +715,7 @@ class HeadNodeIamResources(NodeIamResourcesBase):
                 policy.extend(
                     [
                         iam.PolicyStatement(
+                            sid="AllowManagingReservedCapacity",
                             actions=["ec2:RunInstances", "ec2:CreateFleet", "resource-groups:ListGroupResources"],
                             effect=iam.Effect.ALLOW,
                             resources=capacity_reservation_resource_group_arns,
@@ -749,6 +754,7 @@ class HeadNodeIamResources(NodeIamResourcesBase):
         if self._config.directory_service:
             policy.append(
                 iam.PolicyStatement(
+                    sid="AllowGettingDirectorySecretValue",
                     actions=["secretsmanager:GetSecretValue"],
                     effect=iam.Effect.ALLOW,
                     resources=[self._config.directory_service.password_secret_arn],
@@ -758,6 +764,7 @@ class HeadNodeIamResources(NodeIamResourcesBase):
         if self._config.scheduling.scheduler == "slurm" and self._config.scheduling.settings.database:
             policy.append(
                 iam.PolicyStatement(
+                    sid="AllowGettingSlurmDbSecretValue",
                     actions=["secretsmanager:GetSecretValue"],
                     effect=iam.Effect.ALLOW,
                     resources=[self._config.scheduling.settings.database.password_secret_arn],
@@ -766,6 +773,25 @@ class HeadNodeIamResources(NodeIamResourcesBase):
 
         return policy
 
+    def _add_compute_console_output_policy_statement(self, policy):
+        if self._config.monitoring.logs.cloud_watch.enabled:
+            queue_names = [queue.name for queue in self._config.scheduling.queues]
+            policy.append(
+                iam.PolicyStatement(
+                    sid="EC2GetComputeConsoleOutput",
+                    actions=["ec2:GetConsoleOutput"],
+                    effect=iam.Effect.ALLOW,
+                    resources=[self._format_arn(service="ec2", resource="instance/*")],
+                    conditions={
+                        "StringEquals": {
+                            "aws:ResourceTag/parallelcluster:queue-name": queue_names,
+                            "aws:ResourceTag/parallelcluster:node-type": "Compute",
+                            "aws:ResourceTag/parallelcluster:cluster-name": Stack.of(self).stack_name,
+                        }
+                    },
+                )
+            )
+
     def _generate_head_node_pass_role_resources(self):
         """Return a unique list of ARNs that the head node should be able to use when calling PassRole."""
         resource_iam_path, _ = add_cluster_iam_resource_prefix(
